#ifndef NT2_INCLUDE_FUNCTIONS_POWER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POWER_HPP_INCLUDED

#include <nt2/exponential/include/functions/power.hpp>

#endif
